@@ -72,7 +72,7 @@ void rc_avpair_remove (VALUE_PAIR **list, uint32_t attrid, uint32_t vendorspec)
 	uint64_t vattrid;
 
 	if(vendorspec != VENDOR_NONE)
-		vattrid = VATTRID_SET(attrid, vendorspec);
+		vattrid = RADCLI_VENDOR_ATTR_SET(attrid, vendorspec);
 	else
 		vattrid = attrid;
 
@@ -197,7 +197,7 @@ VALUE_PAIR *rc_avpair_new (rc_handle const *rh, uint32_t attrid, void const *pva
 	uint64_t vattrid;
 
 	if(vendorspec != VENDOR_NONE) {
-		vattrid = VATTRID_SET(attrid, vendorspec);
+		vattrid = RADCLI_VENDOR_ATTR_SET(attrid, vendorspec);
 	} else {
 		vattrid = attrid;
 	}
@@ -300,7 +300,7 @@ VALUE_PAIR *rc_avpair_gen(rc_handle const *rh, VALUE_PAIR *pair, unsigned char c
 	}
 
 	/* Actual processing */
-	attribute = VATTRID_SET(ptr[0], vendorspec);
+	attribute = RADCLI_VENDOR_ATTR_SET(ptr[0], vendorspec);
 	ptr += 2;
 	attrlen -= 2;
 
@@ -432,7 +432,7 @@ shithappens:
  */
 VALUE_PAIR *rc_avpair_get (VALUE_PAIR *vp, uint32_t attrid, uint32_t vendorspec)
 {
-	uint64_t attr = VATTRID_SET(attrid, vendorspec);
+	uint64_t attr = RADCLI_VENDOR_ATTR_SET(attrid, vendorspec);
 
 	for (; vp != NULL && !(attr == vp->attribute); vp = vp->next)
 	{
@@ -607,7 +607,7 @@ int rc_avpair_parse (rc_handle const *rh, char const *buffer, VALUE_PAIR **first
 	DICT_VALUE     *dval;
 	VALUE_PAIR     *pair;
 	VALUE_PAIR     *link;
-	struct tm      *tm;
+	struct tm      *tm, _tm;
 	time_t          timeval;
 
 	mode = PARSE_MODE_NAME;
@@ -743,7 +743,7 @@ int rc_avpair_parse (rc_handle const *rh, char const *buffer, VALUE_PAIR **first
 
 			    case PW_TYPE_DATE:
 				timeval = time (0);
-				tm = localtime (&timeval);
+				tm = localtime_r (&timeval, &_tm);
 				tm->tm_hour = 0;
 				tm->tm_min = 0;
 				tm->tm_sec = 0;
@@ -921,7 +921,8 @@ int rc_avpair_tostr (rc_handle const *rh, VALUE_PAIR *pair, char *name, int ln,
 		break;
 		}
 		case PW_TYPE_DATE: {
-			struct tm *ptm = gmtime((time_t *) & pair->lvalue);
+			struct tm _tm;
+			struct tm *ptm = gmtime_r((time_t *) & pair->lvalue, &_tm);
 			if (ptm == NULL)
 				return -1;
 
